@@ -23,23 +23,23 @@ AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
-# 无效上下文
-FAILEDOPERATION_INVALIDCONTEXT = 'FailedOperation.InvalidContext'
+# 数据库建立链接失败。
+FAILEDOPERATION_DATABASECONNECTERROR = 'FailedOperation.DatabaseConnectError'
 
-# 网络异常
-FAILEDOPERATION_NETWORKERROR = 'FailedOperation.NetworkError'
+# 执行SQL出错。
+FAILEDOPERATION_DATABASEEXECSQLERROR = 'FailedOperation.DatabaseExecSqlError'
+
+# 数据库元信息异常。
+FAILEDOPERATION_DATABASESCHEMAERROR = 'FailedOperation.DatabaseSchemaError'
+
+# 数据库链接点为空。
+FAILEDOPERATION_EMPTYDATABASEENDPOINT = 'FailedOperation.EmptyDatabaseEndpoint'
 
 # 操作失败，后台依赖平台错误。
 FAILEDOPERATION_PLATFORMERROR = 'FailedOperation.PlatformError'
 
-# 查询异常
-FAILEDOPERATION_QUERYERROR = 'FailedOperation.QueryError'
-
-# 查询语句解析错误
-FAILEDOPERATION_SYNTAXERROR = 'FailedOperation.SyntaxError'
-
-# Topic隔离
-FAILEDOPERATION_TOPICISOLATED = 'FailedOperation.TopicIsolated'
+# Instance is resuming, please try connecting again.
+FAILEDOPERATION_TDSQLPAUSED = 'FailedOperation.TdsqlPaused'
 
 # 内部错误。
 INTERNALERROR = 'InternalError'
@@ -47,11 +47,8 @@ INTERNALERROR = 'InternalError'
 # 数据库错误。
 INTERNALERROR_DATABASE = 'InternalError.Database'
 
-# 系统失败。
-INTERNALERROR_SYSTEMFAIL = 'InternalError.SystemFail'
-
-# 服务超时。
-INTERNALERROR_TIMEOUT = 'InternalError.Timeout'
+# 系统内部异常。
+INTERNALERROR_SYS_ERR = 'InternalError.SYS_ERR'
 
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
@@ -65,6 +62,9 @@ INVALIDPARAMETER_ACTION = 'InvalidParameter.Action'
 # 环境ID非法。
 INVALIDPARAMETER_ENVID = 'InvalidParameter.EnvId'
 
+# 请求参数错误。
+INVALIDPARAMETER_INVALID_PARAM = 'InvalidParameter.INVALID_PARAM'
+
 # 路径已存在。
 INVALIDPARAMETER_PATHEXIST = 'InvalidParameter.PathExist'
 
@@ -122,8 +122,14 @@ RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
-# 主题不存在
-RESOURCENOTFOUND_TOPICNOTEXIST = 'ResourceNotFound.TopicNotExist'
+# 数据库实例不存在。
+RESOURCENOTFOUND_INSTANCENOTFOUND = 'ResourceNotFound.InstanceNotFound'
+
+# 请求的云托管服务未找到
+RESOURCENOTFOUND_SERVERNOTFOUND = 'ResourceNotFound.ServerNotFound'
+
+# 表不存在。
+RESOURCENOTFOUND_TABLENOTFOUND = 'ResourceNotFound.TableNotFound'
 
 # 用户不存在。
 RESOURCENOTFOUND_USERNOTEXISTS = 'ResourceNotFound.UserNotExists'
@@ -167,11 +173,8 @@ UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 # 外部代码仓库未授权。
 UNAUTHORIZEDOPERATION_CODEOAUTHUNAUTHORIZED = 'UnauthorizedOperation.CodeOAuthUnauthorized'
 
-# 未知参数错误。
-UNKNOWNPARAMETER = 'UnknownParameter'
-
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 
-# 有正在进行中的任务。
-UNSUPPORTEDOPERATION_TASKEXISTED = 'UnsupportedOperation.TaskExisted'
+# 表数量超过限制。
+UNSUPPORTEDOPERATION_TOOMANYTABLES = 'UnsupportedOperation.TooManyTables'
